==> odata-client-microsoft-dynamics-0.1.47-sources.jar: microsoft/dynamics/crm/complex/CheckIncomingEmailResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ShouldDeliver", 
    "ReasonCode"})
@JsonInclude(Include.NON_NULL)
public class CheckIncomingEmailResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ShouldDeliver")
    protected Boolean shouldDeliver;

    @JsonProperty("ReasonCode")
    protected Integer reasonCode;

    protected CheckIncomingEmailResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse";
    }

    @Property(name="ShouldDeliver")
    @JsonIgnore
    public Optional<Boolean> getShouldDeliver() {
        return Optional.ofNullable(shouldDeliver);
    }

    public CheckIncomingEmailResponse withShouldDeliver(Boolean shouldDeliver) {
        CheckIncomingEmailResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse");
        _x.shouldDeliver = shouldDeliver;
        return _x;
    }

    @Property(name="ReasonCode")
    @JsonIgnore
    public Optional<Integer> getReasonCode() {
        return Optional.ofNullable(reasonCode);
    }

    public CheckIncomingEmailResponse withReasonCode(Integer reasonCode) {
        CheckIncomingEmailResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse");
        _x.reasonCode = reasonCode;
        return _x;
    }

    public CheckIncomingEmailResponse withUnmappedField(String name, String value) {
        CheckIncomingEmailResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean shouldDeliver;
        private Integer reasonCode;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder shouldDeliver(Boolean shouldDeliver) {
            this.shouldDeliver = shouldDeliver;
            this.changedFields = changedFields.add("ShouldDeliver");
            return this;
        }

        public Builder reasonCode(Integer reasonCode) {
            this.reasonCode = reasonCode;
            this.changedFields = changedFields.add("ReasonCode");
            return this;
        }

        public CheckIncomingEmailResponse build() {
            CheckIncomingEmailResponse _x = new CheckIncomingEmailResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse";
            _x.shouldDeliver = shouldDeliver;
            _x.reasonCode = reasonCode;
            return _x;
        }
    }

    private CheckIncomingEmailResponse _copy() {
        CheckIncomingEmailResponse _x = new CheckIncomingEmailResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.shouldDeliver = shouldDeliver;
        _x.reasonCode = reasonCode;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CheckIncomingEmailResponse[");
        b.append("ShouldDeliver=");
        b.append(this.shouldDeliver);
        b.append(", ");
        b.append("ReasonCode=");
        b.append(this.reasonCode);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.58-sources.jar: microsoft/dynamics/crm/complex/CheckIncomingEmailResponse.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Boolean;
import java.lang.Integer;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ShouldDeliver", 
    "ReasonCode"})
@JsonInclude(Include.NON_NULL)
public class CheckIncomingEmailResponse implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ShouldDeliver")
    protected Boolean shouldDeliver;

    @JsonProperty("ReasonCode")
    protected Integer reasonCode;

    protected CheckIncomingEmailResponse() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse";
    }

    @Property(name="ShouldDeliver")
    @JsonIgnore
    public Optional<Boolean> getShouldDeliver() {
        return Optional.ofNullable(shouldDeliver);
    }

    public CheckIncomingEmailResponse withShouldDeliver(Boolean shouldDeliver) {
        CheckIncomingEmailResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse");
        _x.shouldDeliver = shouldDeliver;
        return _x;
    }

    @Property(name="ReasonCode")
    @JsonIgnore
    public Optional<Integer> getReasonCode() {
        return Optional.ofNullable(reasonCode);
    }

    public CheckIncomingEmailResponse withReasonCode(Integer reasonCode) {
        CheckIncomingEmailResponse _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse");
        _x.reasonCode = reasonCode;
        return _x;
    }

    public CheckIncomingEmailResponse withUnmappedField(String name, String value) {
        CheckIncomingEmailResponse _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private Boolean shouldDeliver;
        private Integer reasonCode;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder shouldDeliver(Boolean shouldDeliver) {
            this.shouldDeliver = shouldDeliver;
            this.changedFields = changedFields.add("ShouldDeliver");
            return this;
        }

        public Builder reasonCode(Integer reasonCode) {
            this.reasonCode = reasonCode;
            this.changedFields = changedFields.add("ReasonCode");
            return this;
        }

        public CheckIncomingEmailResponse build() {
            CheckIncomingEmailResponse _x = new CheckIncomingEmailResponse();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.CheckIncomingEmailResponse";
            _x.shouldDeliver = shouldDeliver;
            _x.reasonCode = reasonCode;
            return _x;
        }
    }

    private CheckIncomingEmailResponse _copy() {
        CheckIncomingEmailResponse _x = new CheckIncomingEmailResponse();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.shouldDeliver = shouldDeliver;
        _x.reasonCode = reasonCode;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CheckIncomingEmailResponse[");
        b.append("ShouldDeliver=");
        b.append(this.shouldDeliver);
        b.append(", ");
        b.append("ReasonCode=");
        b.append(this.reasonCode);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
